@@ -207,7 +207,7 @@ class DatasetReference(object):
     """DatasetReferences are pointers to datasets.
 
     See
-    https://cloud.google.com/bigquery/docs/reference/rest/v2/datasets
+    https://cloud.google.com/bigquery/docs/reference/rest/v2/datasets#datasetreference
 
     Args:
         project (str): The ID of the project
@@ -346,13 +346,10 @@ class Dataset(object):
     """Datasets are containers for tables.
 
     See
-    https://cloud.google.com/bigquery/docs/reference/rest/v2/datasets
+    https://cloud.google.com/bigquery/docs/reference/rest/v2/datasets#resource-dataset
 
     Args:
-        dataset_ref (Union[ \
-            :class:`~google.cloud.bigquery.dataset.DatasetReference`, \
-            str, \
-        ]):
+        dataset_ref (Union[google.cloud.bigquery.dataset.DatasetReference, str]):
             A pointer to a dataset. If ``dataset_ref`` is a string, it must
             include both the project ID and the dataset ID, separated by
             ``.``.
@@ -361,6 +358,7 @@ class Dataset(object):
     _PROPERTY_TO_API_FIELD = {
         "access_entries": "access",
         "created": "creationTime",
+        "default_partition_expiration_ms": "defaultPartitionExpirationMs",
         "default_table_expiration_ms": "defaultTableExpirationMs",
         "friendly_name": "friendlyName",
     }
@@ -463,6 +461,34 @@ class Dataset(object):
         """
         return self._properties.get("selfLink")
 
+    @property
+    def default_partition_expiration_ms(self):
+        """Optional[int]: The default partition expiration for all
+        partitioned tables in the dataset, in milliseconds.
+
+        Once this property is set, all newly-created partitioned tables in
+        the dataset will have an ``time_paritioning.expiration_ms`` property
+        set to this value, and changing the value will only affect new
+        tables, not existing ones. The storage in a partition will have an
+        expiration time of its partition time plus this value.
+
+        Setting this property overrides the use of
+        ``default_table_expiration_ms`` for partitioned tables: only one of
+        ``default_table_expiration_ms`` and
+        ``default_partition_expiration_ms`` will be used for any new
+        partitioned table. If you provide an explicit
+        ``time_partitioning.expiration_ms`` when creating or updating a
+        partitioned table, that value takes precedence over the default
+        partition expiration time indicated by this property.
+        """
+        return _helpers._int_or_none(
+            self._properties.get("defaultPartitionExpirationMs")
+        )
+
+    @default_partition_expiration_ms.setter
+    def default_partition_expiration_ms(self, value):
+        self._properties["defaultPartitionExpirationMs"] = _helpers._str_or_none(value)
+
     @property
     def default_table_expiration_ms(self):
         """Union[int, None]: Default expiration time for tables in the dataset
