@@ -55,6 +55,7 @@ from google.cloud.bigquery.schema import SchemaField
 from google.cloud.bigquery.schema import _build_schema_resource
 from google.cloud.bigquery.schema import _parse_schema_resource
 from google.cloud.bigquery.external_config import ExternalConfig
+from google.cloud.bigquery.encryption_configuration import EncryptionConfiguration
 
 
 _LOGGER = logging.getLogger(__name__)
@@ -113,78 +114,11 @@ def _view_use_legacy_sql_getter(table):
         return True
 
 
-class EncryptionConfiguration(object):
-    """Custom encryption configuration (e.g., Cloud KMS keys).
-
-    Args:
-        kms_key_name (str): resource ID of Cloud KMS key used for encryption
-    """
-
-    def __init__(self, kms_key_name=None):
-        self._properties = {}
-        if kms_key_name is not None:
-            self._properties["kmsKeyName"] = kms_key_name
-
-    @property
-    def kms_key_name(self):
-        """str: Resource ID of Cloud KMS key
-
-        Resource ID of Cloud KMS key or :data:`None` if using default
-        encryption.
-        """
-        return self._properties.get("kmsKeyName")
-
-    @kms_key_name.setter
-    def kms_key_name(self, value):
-        self._properties["kmsKeyName"] = value
-
-    @classmethod
-    def from_api_repr(cls, resource):
-        """Construct an encryption configuration from its API representation
-
-        Args:
-            resource (Dict[str, object]):
-                An encryption configuration representation as returned from
-                the API.
-
-        Returns:
-            google.cloud.bigquery.table.EncryptionConfiguration:
-                An encryption configuration parsed from ``resource``.
-        """
-        config = cls()
-        config._properties = copy.deepcopy(resource)
-        return config
-
-    def to_api_repr(self):
-        """Construct the API resource representation of this encryption
-        configuration.
-
-        Returns:
-            Dict[str, object]:
-                Encryption configuration as represented as an API resource
-        """
-        return copy.deepcopy(self._properties)
-
-    def __eq__(self, other):
-        if not isinstance(other, EncryptionConfiguration):
-            return NotImplemented
-        return self.kms_key_name == other.kms_key_name
-
-    def __ne__(self, other):
-        return not self == other
-
-    def __hash__(self):
-        return hash(self.kms_key_name)
-
-    def __repr__(self):
-        return "EncryptionConfiguration({})".format(self.kms_key_name)
-
-
 class TableReference(object):
     """TableReferences are pointers to tables.
 
     See
-    https://cloud.google.com/bigquery/docs/reference/rest/v2/tables
+    https://cloud.google.com/bigquery/docs/reference/rest/v2/tables#tablereference
 
     Args:
         dataset_ref (google.cloud.bigquery.dataset.DatasetReference):
@@ -364,13 +298,10 @@ class Table(object):
     """Tables represent a set of rows whose values correspond to a schema.
 
     See
-    https://cloud.google.com/bigquery/docs/reference/rest/v2/tables
+    https://cloud.google.com/bigquery/docs/reference/rest/v2/tables#resource-table
 
     Args:
-        table_ref (Union[ \
-            :class:`~google.cloud.bigquery.table.TableReference`, \
-            str, \
-        ]):
+        table_ref (Union[google.cloud.bigquery.table.TableReference, str]):
             A pointer to a table. If ``table_ref`` is a string, it must
             included a project ID, dataset ID, and table ID, each separated
             by ``.``.
@@ -388,6 +319,7 @@ class Table(object):
         "view_query": "view",
         "external_data_configuration": "externalDataConfiguration",
         "encryption_configuration": "encryptionConfiguration",
+        "require_partition_filter": "requirePartitionFilter",
     }
 
     def __init__(self, table_ref, schema=None):
@@ -423,6 +355,18 @@ class Table(object):
             self.table_id,
         )
 
+    @property
+    def require_partition_filter(self):
+        """bool: If set to true, queries over the partitioned table require a
+        partition filter that can be used for partition elimination to be
+        specified.
+        """
+        return self._properties.get("requirePartitionFilter")
+
+    @require_partition_filter.setter
+    def require_partition_filter(self, value):
+        self._properties["requirePartitionFilter"] = value
+
     @property
     def schema(self):
         """List[google.cloud.bigquery.schema.SchemaField]: Table's schema.
@@ -469,7 +413,7 @@ class Table(object):
 
     @property
     def encryption_configuration(self):
-        """google.cloud.bigquery.table.EncryptionConfiguration: Custom
+        """google.cloud.bigquery.encryption_configuration.EncryptionConfiguration: Custom
         encryption configuration for the table.
 
         Custom encryption configuration (e.g., Cloud KMS keys) or :data:`None`
@@ -1308,15 +1252,13 @@ class RowIterator(HTTPIterator):
             Defaults to a sensible value set by the API.
         extra_params (Dict[str, object]):
             Extra query string parameters for the API call.
-        table (Union[ \
-            :class:`~google.cloud.bigquery.table.Table`, \
-            :class:`~google.cloud.bigquery.table.TableReference`, \
+        table (Union[
+            google.cloud.bigquery.table.Table,
+            google.cloud.bigquery.table.TableReference,
         ]):
             Optional. The table which these rows belong to, or a reference to
             it. Used to call the BigQuery Storage API to fetch rows.
-        selected_fields (Sequence[ \
-            google.cloud.bigquery.schema.SchemaField, \
-        ]):
+        selected_fields (Sequence[google.cloud.bigquery.schema.SchemaField]):
             Optional. A subset of columns to select from this table.
 
     """
@@ -1481,8 +1423,8 @@ class RowIterator(HTTPIterator):
                 ``'tqdm_gui'``
                   Use the :func:`tqdm.tqdm_gui` function to display a
                   progress bar as a graphical dialog box.
-            bqstorage_client ( \
-                google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient \
+            bqstorage_client (
+                google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient
             ):
                 **Beta Feature** Optional. A BigQuery Storage API client. If
                 supplied, use the faster BigQuery Storage API to fetch rows
@@ -1501,8 +1443,7 @@ class RowIterator(HTTPIterator):
                 from the destination table's schema.
 
         Raises:
-            ValueError:
-                If the :mod:`pyarrow` library cannot be imported.
+            ValueError: If the :mod:`pyarrow` library cannot be imported.
 
         ..versionadded:: 1.17.0
         """
@@ -1567,9 +1508,7 @@ class RowIterator(HTTPIterator):
         """Create a pandas DataFrame by loading all pages of a query.
 
         Args:
-            bqstorage_client ( \
-                google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient \
-            ):
+            bqstorage_client (google.cloud.bigquery_storage_v1beta1.BigQueryStorageClient):
                 **Beta Feature** Optional. A BigQuery Storage API client. If
                 supplied, use the faster BigQuery Storage API to fetch rows
                 from BigQuery. This API is a billable API.
@@ -1584,9 +1523,7 @@ class RowIterator(HTTPIterator):
                 query result tables with the BQ Storage API. When a problem
                 is encountered reading a table, the tabledata.list method
                 from the BigQuery API is used, instead.
-            dtypes ( \
-                Map[str, Union[str, pandas.Series.dtype]] \
-            ):
+            dtypes (Map[str, Union[str, pandas.Series.dtype]]):
                 Optional. A dictionary of column names pandas ``dtype``s. The
                 provided ``dtype`` is used when constructing the series for
                 the column specified. Otherwise, the default pandas behavior
@@ -1680,12 +1617,10 @@ class _EmptyRowIterator(object):
         """[Beta] Create an empty class:`pyarrow.Table`.
 
         Args:
-            progress_bar_type (Optional[str]):
-                Ignored. Added for compatibility with RowIterator.
+            progress_bar_type (Optional[str]): Ignored. Added for compatibility with RowIterator.
 
         Returns:
-            pyarrow.Table:
-                An empty :class:`pyarrow.Table`.
+            pyarrow.Table: An empty :class:`pyarrow.Table`.
         """
         if pyarrow is None:
             raise ValueError(_NO_PYARROW_ERROR)
@@ -1695,16 +1630,12 @@ class _EmptyRowIterator(object):
         """Create an empty dataframe.
 
         Args:
-            bqstorage_client (Any):
-                Ignored. Added for compatibility with RowIterator.
-            dtypes (Any):
-                Ignored. Added for compatibility with RowIterator.
-            progress_bar_type (Any):
-                Ignored. Added for compatibility with RowIterator.
+            bqstorage_client (Any): Ignored. Added for compatibility with RowIterator.
+            dtypes (Any): Ignored. Added for compatibility with RowIterator.
+            progress_bar_type (Any): Ignored. Added for compatibility with RowIterator.
 
         Returns:
-            pandas.DataFrame:
-                An empty :class:`~pandas.DataFrame`.
+            pandas.DataFrame: An empty :class:`~pandas.DataFrame`.
         """
         if pandas is None:
             raise ValueError(_NO_PANDAS_ERROR)
@@ -1738,9 +1669,9 @@ class TimePartitioning(object):
             Number of milliseconds for which to keep the storage for a
             partition.
         require_partition_filter (bool, optional):
-            If set to true, queries over the partitioned table require a
-            partition filter that can be used for partition elimination to be
-            specified.
+            DEPRECATED: Use
+            :attr:`~google.cloud.bigquery.table.Table.require_partition_filter`,
+            instead.
     """
 
     def __init__(
@@ -1793,11 +1724,33 @@ class TimePartitioning(object):
     @property
     def require_partition_filter(self):
         """bool: Specifies whether partition filters are required for queries
+
+        DEPRECATED: Use
+        :attr:`~google.cloud.bigquery.table.Table.require_partition_filter`,
+        instead.
         """
+        warnings.warn(
+            (
+                "TimePartitioning.require_partition_filter will be removed in "
+                "future versions. Please use Table.require_partition_filter "
+                "instead."
+            ),
+            PendingDeprecationWarning,
+            stacklevel=2,
+        )
         return self._properties.get("requirePartitionFilter")
 
     @require_partition_filter.setter
     def require_partition_filter(self, value):
+        warnings.warn(
+            (
+                "TimePartitioning.require_partition_filter will be removed in "
+                "future versions. Please use Table.require_partition_filter "
+                "instead."
+            ),
+            PendingDeprecationWarning,
+            stacklevel=2,
+        )
         self._properties["requirePartitionFilter"] = value
 
     @classmethod
@@ -1872,14 +1825,12 @@ def _item_to_row(iterator, resource):
         added to the iterator after being created, which
         should be done by the caller.
 
-    :type iterator: :class:`~google.api_core.page_iterator.Iterator`
-    :param iterator: The iterator that is currently in use.
+    Args:
+        iterator (google.api_core.page_iterator.Iterator): The iterator that is currently in use.
+        resource (Dict): An item to be converted to a row.
 
-    :type resource: dict
-    :param resource: An item to be converted to a row.
-
-    :rtype: :class:`~google.cloud.bigquery.table.Row`
-    :returns: The next row in the page.
+    Returns:
+        google.cloud.bigquery.table.Row: The next row in the page.
     """
     return Row(
         _helpers._row_tuple_from_json(resource, iterator.schema),
@@ -1910,14 +1861,10 @@ def _tabledata_list_page_columns(schema, response):
 def _rows_page_start(iterator, page, response):
     """Grab total rows when :class:`~google.cloud.iterator.Page` starts.
 
-    :type iterator: :class:`~google.api_core.page_iterator.Iterator`
-    :param iterator: The iterator that is currently in use.
-
-    :type page: :class:`~google.api_core.page_iterator.Page`
-    :param page: The page that was just created.
-
-    :type response: dict
-    :param response: The JSON API response for a page of rows in a table.
+    Args:
+        iterator (google.api_core.page_iterator.Iterator): The iterator that is currently in use.
+        page (google.api_core.page_iterator.Page): The page that was just created.
+        response (Dict): The JSON API response for a page of rows in a table.
     """
     # Make a (lazy) copy of the page in column-oriented format for use in data
     # science packages.
